@@ -1,8 +1,8 @@
-/*  $Id$
+/*  $Id: BurgerSpaceEngine.cpp,v 1.4 2002/04/03 06:11:27 sarrazip Exp $
     BurgerSpaceEngine.cpp - Main engine
 
     burgerspace - A hamburger-smashing video game.
-    Copyright (C) 2001 Pierre Sarrazin <sarrazip@iname.com>
+    Copyright (C) 2001 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -2957,7 +2957,7 @@ BurgerSpaceEngine::displayStartMessage(bool display)
 	static unsigned long firstTick = tickCount;
 
 	if ((tickCount - firstTick) % 64 < 32)
-	    displayMessage("BurgerSpace - by Pierre Sarrazin");
+	    displayMessage("BurgerSpace " VERSION " - by Pierre Sarrazin");
 	else
 	    displayMessage("Press SPACE to start");
     }
